pub trait RequestExtensions {
    fn captures(&self) -> Option<Captures<'_>>;
    fn parsed_captures<C: CaptureParsing>(&self) -> Result<C>;
    fn state<S: Send + Sync + 'static>(&self) -> Option<Arc<S>>;
}
Extensions to http::Request to support easy access to captures and State object

Required Methods

Implementations on Foreign Types

Any captures provided by the matching Regex for the current path

Captures parsed into FromStr types, in tuple format

Copy of any state passed into the router builder using with_state

Implementors